### MMGen version 0.9.3 Release Notes

#### New features:

  - Bob and Alice regtest mode for testing MMGen in a mock two-user environment.
    [Documented](https://github.com/mmgen/mmgen/wiki/MMGen-Quick-Start-with-Regtest-Mode)
    in the wiki, tests added to test suite
  - Compressed P2PKH address support (address type 'C')
  - BCH (Bitcoin Cash) support
  - Segwit (address type 'S') support deployed after Segwit activation on mainnet
  - and, of course, numerous bugfixes and small improvements
